/***********************************************************************
Report standard features of C (K&R, C89, C99, POSIX) and C++
(traditional or 1998) implementations: predefined macros, header
files, data types, and sizes of data types.
[31-May-2005]
***********************************************************************/

#include "config.h"
#include "headers.h"

#define PRINTF (void)printf

float
storef(float x)
{
    return (x);
}

double
store(double x)
{
    return (x);
}

long double
storel(long double x)
{
    return (x);
}

void
show_floats()
{
    float eps;
    int n;

    PRINTF("\nfloat limits:\n");

    eps = (float)1.0;
    n = 0;
    while (storef(eps/(float)2.0) > (float)0.0)
    {
	eps = storef(eps/(float)2.0);
	n--;
    }
    PRINTF("\tsmallest floating-point number: %.8e == 2^(%d)%s\n",
	   (double)eps, n,
	   ((n == -126) ? "\t[IEEE 754 smallest 32-bit normal (subnormals apparently not supported)]" :
	    ((n == -149) ? "\t[IEEE 754 smallest 32-bit subnormal]" : "\t[not IEEE 754 32-bit conformant]")));

    eps = (float)1.0;
    n = 0;
    while (storef((float)1.0 + eps/(float)2.0) != (float)1.0)
    {
	eps = storef(eps/(float)2.0);
	n--;
    }
    PRINTF("\tmachine epsilon:                %.8e == 2^(%d)%s\n",
	   (double)eps, n,
	   ((n == -23) ? "\t[IEEE 754 32-bit conformant]" : "\t[not IEEE 754 32-bit conformant]"));
}


void
show_doubles()
{
    double eps;
    int n;

    PRINTF("\ndouble limits:\n");

    eps = (double)1.0;
    n = 0;
    while (store(eps/(double)2.0) > (double)0.0)
    {
	eps = store(eps/(double)2.0);
	n--;
    }
    PRINTF("\tsmallest floating-point number: %.8e == 2^(%d)%s\n",
	   eps, n,
	   ((n == -1022) ? "\t[IEEE 754 smallest 64-bit normal (subnormals apparently not supported)]" :
	    ((n == -1074) ? "\t[IEEE 754 smallest 64-bit subnormal]" : "\t[not IEEE 754 64-bit conformant]")));

    eps = (double)1.0;
    n = 0;
    while (store((double)1.0 + eps/(double)2.0) != (double)1.0)
    {
	eps = store(eps/(double)2.0);
	n--;
    }
    PRINTF("\tmachine epsilon:                %.8e == 2^(%d)%s\n",
	   eps, n,
	   ((n == -52) ? "\t[IEEE 754 64-bit conformant]" : "\t[not IEEE 754 64-bit conformant]"));
}


void
show_long_doubles()
{
#if defined(HAVE_LONG_DOUBLE)
    long double eps;
    int n;

    PRINTF("\nlong double limits:\n");

    eps = (long double)1.0;
    n = 0;
    while (storel(eps/(long double)2.0) > (long double)0.0)
    {
	eps = storel(eps/(long double)2.0);
	n--;
    }
    PRINTF("\tsmallest floating-point number: %.8e == 2^(%d)%s\n",
	   (double)eps, n,
	   ((n == -16382) ? "\t[IEEE 754 smallest 80-bit or 128-bit normal (subnormals apparently not supported)]" :
	    ((n == -16445) ? "\t[IEEE 754 smallest 80-bit subnormal]" :
	     ((n == -16494) ? "\t[IEEE 754 smallest 128-bit subnormal]" :
	      "\t[not IEEE 754 80-bit or 128-bit conformant]"))));

    eps = (long double)1.0;
    n = 0;
    while (storel((long double)1.0 + eps/(long double)2.0) != (long double)1.0)
    {
	eps = storel(eps/(long double)2.0);
	n--;
    }
    PRINTF("\tmachine epsilon:                %.8e == 2^(%d)%s\n",
	   (double)eps, n,
	   ((n == -63) ? "\t[IEEE 754 80-bit conformant]" :
	    ((n == -112) ? "\t[IEEE 754 128-bit conformant]" :
	     "\t[not IEEE 754 80-bit or 128-bit conformant]")));

    if (sizeof(long double) == sizeof(double))
	PRINTF("\tlong double appears to be just a synonym for double\n");

    if (sizeof(long double) == 10)
	PRINTF("\tlong double appears to be 80-bit value stored in 80-bit (10-byte) field\n");

    if (sizeof(long double) == 12)
	PRINTF("\tlong double appears to be 80-bit value stored in 96-bit (12-byte) field\n");

    if (sizeof(long double) == 16)
	PRINTF("\tlong double appears to be 128-bit value stored in 128-bit (16-byte) field\n");
#endif
}


int
main(void)
{

#if defined(CC)
    PRINTF("Compiler                             = %s\n", CC);
    PRINTF("\n\n");
#endif

    PRINTF("Available standard predefined constant macros...\n");

#if defined(__bool_true_false_are_defined)
    PRINTF("\t__bool_true_false_are_defined = %8ld\n", (long)(__bool_true_false_are_defined + 0L));
#endif

#if defined(__cplusplus)
    PRINTF("\t__cplusplus                  = %8ld\n", (long) (__cplusplus + 0L));
#endif

#if defined(__DATE__)
    PRINTF("\t__DATE__                     = \"%s\"\n", __DATE__);
#endif

#if defined(__FILE__)
    PRINTF("\t__FILE__                     = \"%s\"\n", __FILE__);
#endif

#if defined(__func__)
    PRINTF("\t__func__                     = \"%s\"\n", __func__);
#endif

#if defined(__LINE__)
    PRINTF("\t__LINE__                     = %8ld\n", (long) (__LINE__ + 0L));
#endif

#if defined(__STDC__)
    PRINTF("\t__STDC__                     = %8ld\n", (long) (__STDC__ + 0L));
#endif

#if defined(__STDC_HOSTED__)
    PRINTF("\t__STDC_HOSTED__              = %8ld\n", (long) (__STDC_HOSTED__ + 0L));
#endif

#if defined(__STDC_IEC_559__)
    PRINTF("\t__STDC_IEC_559__             = %8ld\n", (long) (__STDC_IEC_559__ + 0L));
#endif

#if defined(__STDC_IEC_559_COMPLEX__)
    PRINTF("\t__STDC_IEC_559_COMPLEX__     = %8ld\n", (long) (__STDC_IEC_559_COMPLEX__ + 0L));
#endif

#if defined(__STDC_ISO_10646__)
    PRINTF("\t__STDC_ISO_10646__           = %8ld\n", (long) (__STDC_ISO_10646__ + 0L));
#endif

#if defined(__STDC_CONSTANT_MACROS)
    PRINTF("\t__STDC_CONSTANT_MACROS       = %8ld\n", (long) (__STDC_CONSTANT_MACROS + 0L));
#endif

#if defined(__STDC_FORMAT_MACROS)
    PRINTF("\t__STDC_FORMAT_MACROS         = %8ld\n", (long) (__STDC_FORMAT_MACROS + 0L));
#endif

#if defined(__STDC_LIMIT_MACROS)
    PRINTF("\t__STDC_LIMIT_MACROS          = %8ld\n", (long) (__STDC_LIMIT_MACROS + 0L));
#endif

#if defined(__STDC_VERSION__)
    PRINTF("\t__STDC_VERSION__             = %8ld\n", (long) (__STDC_VERSION__ + 0L));
#endif

#if defined(__TIME__)
    PRINTF("\t__TIME__                     = \"%s\"\n", __TIME__);
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Missing standard predefined constant macros...\n");

#if !defined(__bool_true_false_are_defined)
    PRINTF("\t__bool_true_false_are_defined\n");
#endif

#if !defined(__cplusplus)
    PRINTF("\t__cplusplus\n");
#endif

#if !defined(__DATE__)
    PRINTF("\t__DATE__\n");
#endif

#if !defined(__FILE__)
    PRINTF("\t__FILE__\n");
#endif

#if !defined(__func__)
    PRINTF("\t__func__\n");
#endif

#if !defined(__LINE__)
    PRINTF("\t__LINE__\n");
#endif

#if !defined(__STDC__)
    PRINTF("\t__STDC__\n");
#endif

#if !defined(__STDC_HOSTED__)
    PRINTF("\t__STDC_HOSTED__\n");
#endif

#if !defined(__STDC_IEC_559__)
    PRINTF("\t__STDC_IEC_559__\n");
#endif

#if !defined(__STDC_IEC_559_COMPLEX__)
    PRINTF("\t__STDC_IEC_559_COMPLEX__\n");
#endif

#if !defined(__STDC_ISO_10646__)
    PRINTF("\t__STDC_ISO_10646__\n");
#endif

#if !defined(__STDC_CONSTANT_MACROS)
    PRINTF("\t__STDC_CONSTANT_MACROS\n");
#endif

#if !defined(__STDC_FORMAT_MACROS)
    PRINTF("\t__STDC_FORMAT_MACROS\n");
#endif

#if !defined(__STDC_LIMIT_MACROS)
    PRINTF("\t__STDC_LIMIT_MACROS\n");
#endif

#if !defined(__STDC_VERSION__)
    PRINTF("\t__STDC_VERSION__\n");
#endif

#if !defined(__TIME__)
    PRINTF("\t__TIME__\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Available nonstandard but traditional header files...\n");

#if defined(HAVE_SYS_TYPES_H)
    PRINTF("\t<sys/types.h>\n");
#endif

#if defined(HAVE_VARARGS_H)
    PRINTF("\t<varargs.h>\n");
#endif

    PRINTF("\n\n");

   /* ============================================================== */

    PRINTF("Missing nonstandard but traditional header files...\n");

#if !defined(HAVE_SYS_TYPES_H)
    PRINTF("\t<sys/types.h>\n");
#endif

#if !defined(HAVE_VARARGS_H)
    PRINTF("\t<varargs.h>\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Available 1989 Standard C header files...\n");

#if defined(HAVE_ASSERT_H)
    PRINTF("\t<assert.h>\n");
#endif

#if defined(HAVE_CTYPE_H)
    PRINTF("\t<ctype.h>\n");
#endif

#if defined(HAVE_ERRNO_H)
    PRINTF("\t<errno.h>\n");
#endif

#if defined(HAVE_FLOAT_H)
    PRINTF("\t<float.h>\n");
#endif

#if defined(HAVE_LIMITS_H)
    PRINTF("\t<limits.h>\n");
#endif

#if defined(HAVE_LOCALE_H)
    PRINTF("\t<locale.h>\n");
#endif

#if defined(HAVE_MATH_H)
    PRINTF("\t<math.h>\n");
#endif

#if defined(HAVE_SETJMP_H)
    PRINTF("\t<setjmp.h>\n");
#endif

#if defined(HAVE_SIGNAL_H)
    PRINTF("\t<signal.h>\n");
#endif

#if defined(HAVE_STDARG_H)
    PRINTF("\t<stdarg.h>\n");
#endif

#if defined(HAVE_STDDEF_H)
    PRINTF("\t<stddef.h>\n");
#endif

#if defined(HAVE_STDIO_H)
    PRINTF("\t<stdio.h>\n");
#endif

#if defined(HAVE_STDLIB_H)
    PRINTF("\t<stdlib.h>\n");
#endif

#if defined(HAVE_STRING_H)
    PRINTF("\t<string.h>\n");
#endif

#if defined(HAVE_TIME_H)
    PRINTF("\t<time.h>\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Missing 1989 Standard C standard header files...\n");
#if !defined(HAVE_ASSERT_H)
    PRINTF("\t<assert.h>\n");
#endif

#if !defined(HAVE_CTYPE_H)
    PRINTF("\t<ctype.h>\n");
#endif

#if !defined(HAVE_ERRNO_H)
    PRINTF("\t<errno.h>\n");
#endif

#if !defined(HAVE_FLOAT_H)
    PRINTF("\t<float.h>\n");
#endif

#if !defined(HAVE_LIMITS_H)
    PRINTF("\t<limits.h>\n");
#endif

#if !defined(HAVE_LOCALE_H)
    PRINTF("\t<locale.h>\n");
#endif

#if !defined(HAVE_MATH_H)
    PRINTF("\t<math.h>\n");
#endif

#if !defined(HAVE_SETJMP_H)
    PRINTF("\t<setjmp.h>\n");
#endif

#if !defined(HAVE_SIGNAL_H)
    PRINTF("\t<signal.h>\n");
#endif

#if !defined(HAVE_STDARG_H)
    PRINTF("\t<stdarg.h>\n");
#endif

#if !defined(HAVE_STDDEF_H)
    PRINTF("\t<stddef.h>\n");
#endif

#if !defined(HAVE_STDIO_H)
    PRINTF("\t<stdio.h>\n");
#endif

#if !defined(HAVE_STDLIB_H)
    PRINTF("\t<stdlib.h>\n");
#endif

#if !defined(HAVE_STRING_H)
    PRINTF("\t<string.h>\n");
#endif

#if !defined(HAVE_TIME_H)
    PRINTF("\t<time.h>\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Available additional 1999 Standard C header files...\n");

#if defined(HAVE_COMPLEX_H)
    PRINTF("\t<complex.h>\n");
#endif

#if defined(HAVE_FENV_H)
    PRINTF("\t<fenv.h>\n");
#endif

#if defined(HAVE_INTTYPES_H)
    PRINTF("\t<inttypes.h>\n");
#endif

#if defined(HAVE_ISO646_H)
    PRINTF("\t<iso646.h>\n");
#endif

#if defined(HAVE_STDBOOL_H)
    PRINTF("\t<stdbool.h>\n");
#endif

#if defined(HAVE_STDINT_H)
    PRINTF("\t<stdint.h>\n");
#endif

#if defined(HAVE_TGMATH_H)
    PRINTF("\t<tgmath.h>\n");
#endif

#if defined(HAVE_WCHAR_H)
    PRINTF("\t<wchar.h>\n");
#endif

#if defined(HAVE_WCTYPE_H)
    PRINTF("\t<wctype.h>\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Missing additional 1999 Standard C standard header files...\n");

#if !defined(HAVE_COMPLEX_H)
    PRINTF("\t<complex.h>\n");
#endif

#if !defined(HAVE_FENV_H)
    PRINTF("\t<fenv.h>\n");
#endif

#if !defined(HAVE_INTTYPES_H)
    PRINTF("\t<inttypes.h>\n");
#endif

#if !defined(HAVE_ISO646_H)
    PRINTF("\t<iso646.h>\n");
#endif

#if !defined(HAVE_STDBOOL_H)
    PRINTF("\t<stdbool.h>\n");
#endif

#if !defined(HAVE_STDINT_H)
    PRINTF("\t<stdint.h>\n");
#endif

#if !defined(HAVE_TGMATH_H)
    PRINTF("\t<tgmath.h>\n");
#endif

#if !defined(HAVE_WCHAR_H)
    PRINTF("\t<wchar.h>\n");
#endif

#if !defined(HAVE_WCTYPE_H)
    PRINTF("\t<wctype.h>\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Available additional POSIX (IEEE Std 1003.1-2001) header files...\n");
#if defined(HAVE_AIO_H)
    PRINTF("\t<aio.h>\n");
#endif

#if defined(HAVE_ARPA_INET_H)
    PRINTF("\t<arpa/inet.h>\n");
#endif

#if defined(HAVE_CPIO_H)
    PRINTF("\t<cpio.h>\n");
#endif

#if defined(HAVE_DIRENT_H)
    PRINTF("\t<dirent.h>\n");
#endif

#if defined(HAVE_DLFCN_H)
    PRINTF("\t<dlfcn.h>\n");
#endif

#if defined(HAVE_FCNTL_H)
    PRINTF("\t<fcntl.h>\n");
#endif

#if defined(HAVE_FMTMSG_H)
    PRINTF("\t<fmtmsg.h>\n");
#endif

#if defined(HAVE_FNMATCH_H)
    PRINTF("\t<fnmatch.h>\n");
#endif

#if defined(HAVE_FTW_H)
    PRINTF("\t<ftw.h>\n");
#endif

#if defined(HAVE_GLOB_H)
    PRINTF("\t<glob.h>\n");
#endif

#if defined(HAVE_GRP_H)
    PRINTF("\t<grp.h>\n");
#endif

#if defined(HAVE_ICONV_H)
    PRINTF("\t<iconv.h>\n");
#endif

#if defined(HAVE_LANGINFO_H)
    PRINTF("\t<langinfo.h>\n");
#endif

#if defined(HAVE_LIBGEN_H)
    PRINTF("\t<libgen.h>\n");
#endif

#if defined(HAVE_MONETARY_H)
    PRINTF("\t<monetary.h>\n");
#endif

#if defined(HAVE_MQUEUE_H)
    PRINTF("\t<mqueue.h>\n");
#endif

#if defined(HAVE_NDBM_H)
    PRINTF("\t<ndbm.h>\n");
#endif

#if defined(HAVE_NET_IF_H)
    PRINTF("\t<net/if.h>\n");
#endif

#if defined(HAVE_NETDB_H)
    PRINTF("\t<netdb.h>\n");
#endif

#if defined(HAVE_NETINET_IN_H)
    PRINTF("\t<netinet/in.h>\n");
#endif

#if defined(HAVE_NETINET_TCP_H)
    PRINTF("\t<netinet/tcp.h>\n");
#endif

#if defined(HAVE_NL_TYPES_H)
    PRINTF("\t<nl_types.h>\n");
#endif

#if defined(HAVE_POLL_H)
    PRINTF("\t<poll.h>\n");
#endif

#if defined(HAVE_PTHREAD_H)
    PRINTF("\t<pthread.h>\n");
#endif

#if defined(HAVE_PWD_H)
    PRINTF("\t<pwd.h>\n");
#endif

#if defined(HAVE_REGEX_H)
    PRINTF("\t<regex.h>\n");
#endif

#if defined(HAVE_SCHED_H)
    PRINTF("\t<sched.h>\n");
#endif

#if defined(HAVE_SEARCH_H)
    PRINTF("\t<search.h>\n");
#endif

#if defined(HAVE_SEMAPHORE_H)
    PRINTF("\t<semaphore.h>\n");
#endif

#if defined(HAVE_SPAWN_H)
    PRINTF("\t<spawn.h>\n");
#endif

#if defined(HAVE_STRINGS_H)
    PRINTF("\t<strings.h>\n");
#endif

#if defined(HAVE_STROPTS_H)
    PRINTF("\t<stropts.h>\n");
#endif

#if defined(HAVE_SYS_IPC_H)
    PRINTF("\t<sys/ipc.h>\n");
#endif

#if defined(HAVE_SYS_MMAN_H)
    PRINTF("\t<sys/mman.h>\n");
#endif

#if defined(HAVE_SYS_MSG_H)
    PRINTF("\t<sys/msg.h>\n");
#endif

#if defined(HAVE_SYS_RESOURCE_H)
    PRINTF("\t<sys/resource.h>\n");
#endif

#if defined(HAVE_SYS_SELECT_H)
    PRINTF("\t<sys/select.h>\n");
#endif

#if defined(HAVE_SYS_SEM_H)
    PRINTF("\t<sys/sem.h>\n");
#endif

#if defined(HAVE_SYS_SHM_H)
    PRINTF("\t<sys/shm.h>\n");
#endif

#if defined(HAVE_SYS_SOCKET_H)
    PRINTF("\t<sys/socket.h>\n");
#endif

#if defined(HAVE_SYS_STAT_H)
    PRINTF("\t<sys/stat.h>\n");
#endif

#if defined(HAVE_SYS_STATVFS_H)
    PRINTF("\t<sys/statvfs.h>\n");
#endif

#if defined(HAVE_SYS_TIME_H)
    PRINTF("\t<sys/time.h>\n");
#endif

#if defined(HAVE_SYS_TIMEB_H)
    PRINTF("\t<sys/timeb.h>\n");
#endif

#if defined(HAVE_SYS_TIMES_H)
    PRINTF("\t<sys/times.h>\n");
#endif

#if defined(HAVE_SYS_TYPES_H)
    PRINTF("\t<sys/types.h>\n");
#endif

#if defined(HAVE_SYS_UIO_H)
    PRINTF("\t<sys/uio.h>\n");
#endif

#if defined(HAVE_SYS_UN_H)
    PRINTF("\t<sys/un.h>\n");
#endif

#if defined(HAVE_SYS_UTSNAME_H)
    PRINTF("\t<sys/utsname.h>\n");
#endif

#if defined(HAVE_SYS_WAIT_H)
    PRINTF("\t<sys/wait.h>\n");
#endif

#if defined(HAVE_SYSLOG_H)
    PRINTF("\t<syslog.h>\n");
#endif

#if defined(HAVE_TAR_H)
    PRINTF("\t<tar.h>\n");
#endif

#if defined(HAVE_TERMIOS_H)
    PRINTF("\t<termios.h>\n");
#endif

#if defined(HAVE_TRACE_H)
    PRINTF("\t<trace.h>\n");
#endif

#if defined(HAVE_UCONTEXT_H)
    PRINTF("\t<ucontext.h>\n");
#endif

#if defined(HAVE_ULIMIT_H)
    PRINTF("\t<ulimit.h>\n");
#endif

#if defined(HAVE_UNISTD_H)
    PRINTF("\t<unistd.h>\n");
#endif

#if defined(HAVE_UTIME_H)
    PRINTF("\t<utime.h>\n");
#endif

#if defined(HAVE_UTMPX_H)
    PRINTF("\t<utmpx.h>\n");
#endif

#if defined(HAVE_WORDEXP_H)
    PRINTF("\t<wordexp.h>\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Missing additional POSIX (IEEE Std 1003.1-2001) header files...\n");

#if !defined(HAVE_AIO_H)
    PRINTF("\t<aio.h>\n");
#endif

#if !defined(HAVE_ARPA_INET_H)
    PRINTF("\t<arpa/inet.h>\n");
#endif

#if !defined(HAVE_CPIO_H)
    PRINTF("\t<cpio.h>\n");
#endif

#if !defined(HAVE_DIRENT_H)
    PRINTF("\t<dirent.h>\n");
#endif

#if !defined(HAVE_DLFCN_H)
    PRINTF("\t<dlfcn.h>\n");
#endif

#if !defined(HAVE_FCNTL_H)
    PRINTF("\t<fcntl.h>\n");
#endif

#if !defined(HAVE_FMTMSG_H)
    PRINTF("\t<fmtmsg.h>\n");
#endif

#if !defined(HAVE_FNMATCH_H)
    PRINTF("\t<fnmatch.h>\n");
#endif

#if !defined(HAVE_FTW_H)
    PRINTF("\t<ftw.h>\n");
#endif

#if !defined(HAVE_GLOB_H)
    PRINTF("\t<glob.h>\n");
#endif

#if !defined(HAVE_GRP_H)
    PRINTF("\t<grp.h>\n");
#endif

#if !defined(HAVE_ICONV_H)
    PRINTF("\t<iconv.h>\n");
#endif

#if !defined(HAVE_LANGINFO_H)
    PRINTF("\t<langinfo.h>\n");
#endif

#if !defined(HAVE_LIBGEN_H)
    PRINTF("\t<libgen.h>\n");
#endif

#if !defined(HAVE_MONETARY_H)
    PRINTF("\t<monetary.h>\n");
#endif

#if !defined(HAVE_MQUEUE_H)
    PRINTF("\t<mqueue.h>\n");
#endif

#if !defined(HAVE_NDBM_H)
    PRINTF("\t<ndbm.h>\n");
#endif

#if !defined(HAVE_NET_IF_H)
    PRINTF("\t<net/if.h>\n");
#endif

#if !defined(HAVE_NETDB_H)
    PRINTF("\t<netdb.h>\n");
#endif

#if !defined(HAVE_NETINET_IN_H)
    PRINTF("\t<netinet/in.h>\n");
#endif

#if !defined(HAVE_NETINET_TCP_H)
    PRINTF("\t<netinet/tcp.h>\n");
#endif

#if !defined(HAVE_NL_TYPES_H)
    PRINTF("\t<nl_types.h>\n");
#endif

#if !defined(HAVE_POLL_H)
    PRINTF("\t<poll.h>\n");
#endif

#if !defined(HAVE_PTHREAD_H)
    PRINTF("\t<pthread.h>\n");
#endif

#if !defined(HAVE_PWD_H)
    PRINTF("\t<pwd.h>\n");
#endif

#if !defined(HAVE_REGEX_H)
    PRINTF("\t<regex.h>\n");
#endif

#if !defined(HAVE_SCHED_H)
    PRINTF("\t<sched.h>\n");
#endif

#if !defined(HAVE_SEARCH_H)
    PRINTF("\t<search.h>\n");
#endif

#if !defined(HAVE_SEMAPHORE_H)
    PRINTF("\t<semaphore.h>\n");
#endif

#if !defined(HAVE_SPAWN_H)
    PRINTF("\t<spawn.h>\n");
#endif

#if !defined(HAVE_STRINGS_H)
    PRINTF("\t<strings.h>\n");
#endif

#if !defined(HAVE_STROPTS_H)
    PRINTF("\t<stropts.h>\n");
#endif

#if !defined(HAVE_SYS_IPC_H)
    PRINTF("\t<sys/ipc.h>\n");
#endif

#if !defined(HAVE_SYS_MMAN_H)
    PRINTF("\t<sys/mman.h>\n");
#endif

#if !defined(HAVE_SYS_MSG_H)
    PRINTF("\t<sys/msg.h>\n");
#endif

#if !defined(HAVE_SYS_RESOURCE_H)
    PRINTF("\t<sys/resource.h>\n");
#endif

#if !defined(HAVE_SYS_SELECT_H)
    PRINTF("\t<sys/select.h>\n");
#endif

#if !defined(HAVE_SYS_SEM_H)
    PRINTF("\t<sys/sem.h>\n");
#endif

#if !defined(HAVE_SYS_SHM_H)
    PRINTF("\t<sys/shm.h>\n");
#endif

#if !defined(HAVE_SYS_SOCKET_H)
    PRINTF("\t<sys/socket.h>\n");
#endif

#if !defined(HAVE_SYS_STAT_H)
    PRINTF("\t<sys/stat.h>\n");
#endif

#if !defined(HAVE_SYS_STATVFS_H)
    PRINTF("\t<sys/statvfs.h>\n");
#endif

#if !defined(HAVE_SYS_TIME_H)
    PRINTF("\t<sys/time.h>\n");
#endif

#if !defined(HAVE_SYS_TIMEB_H)
    PRINTF("\t<sys/timeb.h>\n");
#endif

#if !defined(HAVE_SYS_TIMES_H)
    PRINTF("\t<sys/times.h>\n");
#endif

#if !defined(HAVE_SYS_TYPES_H)
    PRINTF("\t<sys/types.h>\n");
#endif

#if !defined(HAVE_SYS_UIO_H)
    PRINTF("\t<sys/uio.h>\n");
#endif

#if !defined(HAVE_SYS_UN_H)
    PRINTF("\t<sys/un.h>\n");
#endif

#if !defined(HAVE_SYS_UTSNAME_H)
    PRINTF("\t<sys/utsname.h>\n");
#endif

#if !defined(HAVE_SYS_WAIT_H)
    PRINTF("\t<sys/wait.h>\n");
#endif

#if !defined(HAVE_SYSLOG_H)
    PRINTF("\t<syslog.h>\n");
#endif

#if !defined(HAVE_TAR_H)
    PRINTF("\t<tar.h>\n");
#endif

#if !defined(HAVE_TERMIOS_H)
    PRINTF("\t<termios.h>\n");
#endif

#if !defined(HAVE_TRACE_H)
    PRINTF("\t<trace.h>\n");
#endif

#if !defined(HAVE_UCONTEXT_H)
    PRINTF("\t<ucontext.h>\n");
#endif

#if !defined(HAVE_ULIMIT_H)
    PRINTF("\t<ulimit.h>\n");
#endif

#if !defined(HAVE_UNISTD_H)
    PRINTF("\t<unistd.h>\n");
#endif

#if !defined(HAVE_UTIME_H)
    PRINTF("\t<utime.h>\n");
#endif

#if !defined(HAVE_UTMPX_H)
    PRINTF("\t<utmpx.h>\n");
#endif

#if !defined(HAVE_WORDEXP_H)
    PRINTF("\t<wordexp.h>\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Character range and sign...\n");
    PRINTF("\tCHAR_MIN                     \t= %+4d\n", (int)CHAR_MIN);
    PRINTF("\tCHAR_MAX                     \t= %+4d\n", (int)CHAR_MAX);

#if defined(SCHAR_MIN) && defined(SCHAR_MAX)
    PRINTF("\tSCHAR_MIN                    \t= %+4d\n", (int)SCHAR_MIN);
    PRINTF("\tSCHAR_MAX                    \t= %+4d\n", (int)SCHAR_MAX);
#else
    PRINTF("\tSCHAR_MIN                    \t= UNDEFINED\n");
    PRINTF("\tSCHAR_MAX                    \t= UNDEFINED\n");
#endif

#if defined(UCHAR_MAX)
    PRINTF("\tUCHAR_MAX                    \t= %+4d\n", (int)UCHAR_MAX);
#else
    PRINTF("\tUCHAR_MAX                    \t= UNDEFINED\n");
#endif

    PRINTF("\tchar type is          %s\n", (int)((char)(-1)) < 0 ? "signed" : "unsigned");
    PRINTF("\tsigned char type is   %s\n", (int)((signed char)(-1)) < 0 ? "signed" : "unsigned [WRONG!]");
    PRINTF("\tunsigned char type is %s\n", (int)((unsigned char)(-1)) < 0 ? "signed [WRONG!]" : "unsigned");

    PRINTF("\n\n");

#if defined(HAVE_WCHAR_T) && defined(WCHAR_MAX) && defined(WCHAR_MIN)

    /* ============================================================== */

    PRINTF("Wide character range and sign...\n");
    PRINTF("\tWCHAR_MIN                     \t= %+10d\n", (int)(wchar_t)WCHAR_MIN);
    PRINTF("\tWCHAR_MAX                     \t= %+10d\n", (int)(wchar_t)WCHAR_MAX);
    PRINTF("\twchar_t type is       %s\n", (int)((wchar_t)(-1)) < 0 ? "signed" : "unsigned");

    PRINTF("\n\n");

#endif

    /* ============================================================== */

    PRINTF("Pointer sizes...\n");
    PRINTF("\tsizeof(char*)                \t= %4u\n", (unsigned int)sizeof(char*));
    PRINTF("\tsizeof(void*)                \t= %4u\n", (unsigned int)sizeof(void*));
    PRINTF("\tsizeof(void(*)(void))        \t= %4u\n", (unsigned int)sizeof(void(*)(void)));
    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Integer sizes...\n");
    PRINTF("\tsizeof(char)                 \t= %4u\n", (unsigned int)sizeof(char));
    PRINTF("\tsizeof(short)                \t= %4u\n", (unsigned int)sizeof(short));
    PRINTF("\tsizeof(int)                  \t= %4u\n", (unsigned int)sizeof(int));
    PRINTF("\tsizeof(long)                 \t= %4u\n", (unsigned int)sizeof(long));

#if defined(HAVE_LONG_LONG)
    PRINTF("\tsizeof(long long)            \t= %4u\n", (unsigned int)sizeof(long long));
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Integer-like sizes...\n");

#if defined(HAVE_CLOCK_T)
    PRINTF("\tsizeof(clock_t)              \t= %4u\n", (unsigned int)sizeof(clock_t));
#endif

#if defined(HAVE_DIV_T)
    PRINTF("\tsizeof(div_t)                \t= %4u\n", (unsigned int)sizeof(div_t));
#endif

#if defined(HAVE_FPOS_T)
    PRINTF("\tsizeof(fpos_t)               \t= %4u\n", (unsigned int)sizeof(fpos_t));
#endif

#if defined(HAVE_INTMAX_T)
    PRINTF("\tsizeof(intmax_t)             \t= %4u\n", (unsigned int)sizeof(intmax_t));
#endif

#if defined(HAVE_LDIV_T)
    PRINTF("\tsizeof(ldiv_t)               \t= %4u\n", (unsigned int)sizeof(ldiv_t));
#endif

#if defined(HAVE_OFF_T)
    PRINTF("\tsizeof(off_t)                \t= %4u\n", (unsigned int)sizeof(off_t));
#endif

#if defined(HAVE_PTRDIFF_T)
    PRINTF("\tsizeof(ptrdiff_t)            \t= %4u\n", (unsigned int)sizeof(ptrdiff_t));
#endif

#if defined(HAVE_SIG_ATOMIC_T)
    PRINTF("\tsizeof(sig_atomic_t)         \t= %4u\n", (unsigned int)sizeof(sig_atomic_t));
#endif

#if defined(HAVE_SIZE_T)
    PRINTF("\tsizeof(size_t)               \t= %4u\n", (unsigned int)sizeof(size_t));
#endif

#if defined(HAVE_TIME_T)
    PRINTF("\tsizeof(time_t)               \t= %4u\n", (unsigned int)sizeof(time_t));
#endif

#if defined(HAVE_UINTMAX_T)
    PRINTF("\tsizeof(uintmax_t)            \t= %4u\n", (unsigned int)sizeof(uintmax_t));
#endif

#if defined(HAVE_WCHAR_T)
    PRINTF("\tsizeof(wchar_t)              \t= %4u\n", (unsigned int)sizeof(wchar_t));
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("C++ 1998 integer-like sizes...\n");

#if defined(HAVE_NOTHROW_T)
    PRINTF("\tsizeof(nothrow_t)            \t= %4u\n", (unsigned int)sizeof(nothrow_t));
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("C99 integer-like sizes...\n");

#if defined(HAVE_DOUBLE_T)
    PRINTF("\tsizeof(double_t)             \t= %4u\n", (unsigned int)sizeof(double_t));
#endif

#if defined(HAVE_FENV_T)
    PRINTF("\tsizeof(fenv_t)               \t= %4u\n", (unsigned int)sizeof(fenv_t));
#endif

#if defined(HAVE_FEXCEPT_T)
    PRINTF("\tsizeof(fexcept_t)            \t= %4u\n", (unsigned int)sizeof(fexcept_t));
#endif

#if defined(HAVE_FLOAT_T)
    PRINTF("\tsizeof(float_t)              \t= %4u\n", (unsigned int)sizeof(float_t));
#endif

#if defined(HAVE_IMAXDIV_T)
    PRINTF("\tsizeof(imaxdiv_t)            \t= %4u\n", (unsigned int)sizeof(imaxdiv_t));
#endif

#if defined(HAVE_INT8_T)
    PRINTF("\tsizeof(int8_t)               \t= %4u\n", (unsigned int)sizeof(int8_t));
#endif

#if defined(HAVE_INT_FAST16_T)
    PRINTF("\tsizeof(int_fast16_t)         \t= %4u\n", (unsigned int)sizeof(int_fast16_t));
#endif

#if defined(HAVE_INT_FAST32_T)
    PRINTF("\tsizeof(int_fast32_t)         \t= %4u\n", (unsigned int)sizeof(int_fast32_t));
#endif

#if defined(HAVE_INT_FAST64_T)
    PRINTF("\tsizeof(int_fast64_t)         \t= %4u\n", (unsigned int)sizeof(int_fast64_t));
#endif

#if defined(HAVE_INT_FAST8_T)
    PRINTF("\tsizeof(int_fast8_t)          \t= %4u\n", (unsigned int)sizeof(int_fast8_t));
#endif

#if defined(HAVE_INT_LEAST16_T)
    PRINTF("\tsizeof(int_least16_t)        \t= %4u\n", (unsigned int)sizeof(int_least16_t));
#endif

#if defined(HAVE_INT_LEAST32_T)
    PRINTF("\tsizeof(int_least32_t)        \t= %4u\n", (unsigned int)sizeof(int_least32_t));
#endif

#if defined(HAVE_INT_LEAST64_T)
    PRINTF("\tsizeof(int_least64_t)        \t= %4u\n", (unsigned int)sizeof(int_least64_t));
#endif

#if defined(HAVE_INT_LEAST8_T)
    PRINTF("\tsizeof(int_least8_t)         \t= %4u\n", (unsigned int)sizeof(int_least8_t));
#endif

#if defined(HAVE_INTPTR_T)
    PRINTF("\tsizeof(intptr_t)             \t= %4u\n", (unsigned int)sizeof(intptr_t));
#endif

#if defined(HAVE_LLDIV_T)
    PRINTF("\tsizeof(lldiv_t)              \t= %4u\n", (unsigned int)sizeof(lldiv_t));
#endif

#if defined(HAVE_MBSTATE_T)
    PRINTF("\tsizeof(mbstate_t)            \t= %4u\n", (unsigned int)sizeof(mbstate_t));
#endif

#if defined(HAVE_SSIZE_T)
    PRINTF("\tsizeof(ssize_t)              \t= %4u\n", (unsigned int)sizeof(ssize_t)); /* Posix.2 */
#endif

#if defined(HAVE_UINT_FAST16_T)
    PRINTF("\tsizeof(uint_fast16_t)        \t= %4u\n", (unsigned int)sizeof(uint_fast16_t));
#endif

#if defined(HAVE_UINT_FAST32_T)
    PRINTF("\tsizeof(uint_fast32_t)        \t= %4u\n", (unsigned int)sizeof(uint_fast32_t));
#endif

#if defined(HAVE_UINT_FAST64_T)
    PRINTF("\tsizeof(uint_fast64_t)        \t= %4u\n", (unsigned int)sizeof(uint_fast64_t));
#endif

#if defined(HAVE_UINT_FAST8_T)
    PRINTF("\tsizeof(uint_fast8_t)         \t= %4u\n", (unsigned int)sizeof(uint_fast8_t));
#endif

#if defined(HAVE_UINT_LEAST16_T)
    PRINTF("\tsizeof(uint_least16_t)       \t= %4u\n", (unsigned int)sizeof(uint_least16_t));
#endif

#if defined(HAVE_UINT_LEAST32_T)
    PRINTF("\tsizeof(uint_least32_t)       \t= %4u\n", (unsigned int)sizeof(uint_least32_t));
#endif

#if defined(HAVE_UINT_LEAST64_T)
    PRINTF("\tsizeof(uint_least64_t)       \t= %4u\n", (unsigned int)sizeof(uint_least64_t));
#endif

#if defined(HAVE_UINT_LEAST8_T)
    PRINTF("\tsizeof(uint_least8_t)        \t= %4u\n", (unsigned int)sizeof(uint_least8_t));
#endif

#if defined(HAVE_UINTPTR_T)
    PRINTF("\tsizeof(uintptr_t)            \t= %4u\n", (unsigned int)sizeof(uintptr_t));
#endif

#if defined(HAVE_WCHAR_T)
    PRINTF("\tsizeof(wchar_t)              \t= %4u\n", (unsigned int)sizeof(wchar_t));
#endif

#if defined(HAVE_WCTRANS_T)
    PRINTF("\tsizeof(wctrans_t)            \t= %4u\n", (unsigned int)sizeof(wctrans_t));
#endif

#if defined(HAVE_WCTYPE_T)
    PRINTF("\tsizeof(wctype_t)             \t= %4u\n", (unsigned int)sizeof(wctype_t));
#endif

#if defined(HAVE_WINT_T)
    PRINTF("\tsizeof(wint_t)               \t= %4u\n", (unsigned int)sizeof(wint_t));
#endif

#if defined(HAVE__BOOL)
    PRINTF("\tsizeof(_Bool)                \t= %4u\n", (unsigned int)sizeof(_Bool));
#endif

#if defined(HAVE__COMPLEX)
    PRINTF("\tsizeof(_Complex)             \t= %4u\n", (unsigned int)sizeof(_Complex));
#endif

#if defined(HAVE__IMAGINARY)
    PRINTF("\tsizeof(_Imaginary)           \t= %4u\n", (unsigned int)sizeof(_Imaginary));
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Floating-point sizes...\n");
    PRINTF("\tsizeof(float)                \t= %4u\n", (unsigned int)sizeof(float));
    PRINTF("\tsizeof(double)               \t= %4u\n", (unsigned int)sizeof(double));

#if defined(HAVE_LONG_DOUBLE)
    PRINTF("\tsizeof(long double)          \t= %4u\n", (unsigned int)sizeof(long double));
#endif

    PRINTF("\n\n");

    /* ============================================================== */

    PRINTF("Missing data types...\n");

#if !defined(HAVE_CLOCK_T)
    PRINTF("\tclock_t\n");
#endif

#if !defined(HAVE_DIV_T)
    PRINTF("\tdiv_t\n");
#endif

#if !defined(HAVE_DOUBLE_T)
    PRINTF("\tdouble_t\n");
#endif

#if !defined(HAVE_FENV_T)
    PRINTF("\tfenv_t\n");
#endif

#if !defined(HAVE_FEXCEPT_T)
    PRINTF("\tfexcept_t\n");
#endif

#if !defined(HAVE_FLOAT_T)
    PRINTF("\tfloat_t\n");
#endif

#if !defined(HAVE_FPOS_T)
    PRINTF("\tfpos_t\n");
#endif

#if !defined(HAVE_IMAXDIV_T)
    PRINTF("\timaxdiv_t\n");
#endif

#if !defined(HAVE_INT8_T)
    PRINTF("\tint8_t\n");
#endif

#if !defined(HAVE_INTMAX_T)
    PRINTF("\tintmax_t\n");
#endif

#if !defined(HAVE_INTPTR_T)
    PRINTF("\tintptr_t\n");
#endif

#if !defined(HAVE_INT_FAST16_T)
    PRINTF("\tint_fast16_t\n");
#endif

#if !defined(HAVE_INT_FAST32_T)
    PRINTF("\tint_fast32_t\n");
#endif

#if !defined(HAVE_INT_FAST64_T)
    PRINTF("\tint_fast64_t\n");
#endif

#if !defined(HAVE_INT_FAST8_T)
    PRINTF("\tint_fast8_t\n");
#endif

#if !defined(HAVE_INT_LEAST16_T)
    PRINTF("\tint_least16_t\n");
#endif

#if !defined(HAVE_INT_LEAST32_T)
    PRINTF("\tint_least32_t\n");
#endif

#if !defined(HAVE_INT_LEAST64_T)
    PRINTF("\tint_least64_t\n");
#endif

#if !defined(HAVE_INT_LEAST8_T)
    PRINTF("\tint_least8_t\n");
#endif

#if !defined(HAVE_LDIV_T)
    PRINTF("\tldiv_t\n");
#endif

#if !defined(HAVE_LLDIV_T)
    PRINTF("\tlldiv_t\n");
#endif

#if !defined(HAVE_LONG_DOUBLE)
    PRINTF("\tlong double\n");
#endif

#if !defined(HAVE_LONG_LONG)
    PRINTF("\tlong long\n");
#endif

#if !defined(HAVE_MBSTATE_T)
    PRINTF("\tmbstate_t\n");
#endif

#if !defined(HAVE_NOTHROW_T)
    PRINTF("\tnothrow_t\n");
#endif

#if !defined(HAVE_OFF_T)
    PRINTF("\toff_t\n");
#endif

#if !defined(HAVE_PTRDIFF_T)
    PRINTF("\tptrdiff_t\n");
#endif

#if !defined(HAVE_SIG_ATOMIC_T)
    PRINTF("\tsig_atomic_t\n");
#endif

#if !defined(HAVE_SIZE_T)
    PRINTF("\tsize_t\n");
#endif

#if !defined(HAVE_SSIZE_T)
    PRINTF("\tssize_t\n");
#endif

#if !defined(HAVE_TIME_T)
    PRINTF("\ttime_t\n");
#endif

#if !defined(HAVE_UINTMAX_T)
    PRINTF("\tuintmax_t\n");
#endif

#if !defined(HAVE_UINTPTR_T)
    PRINTF("\tuintptr_t\n");
#endif

#if !defined(HAVE_UINT_FAST16_T)
    PRINTF("\tuint_fast16_t\n");
#endif

#if !defined(HAVE_UINT_FAST32_T)
    PRINTF("\tuint_fast32_t\n");
#endif

#if !defined(HAVE_UINT_FAST64_T)
    PRINTF("\tuint_fast64_t\n");
#endif

#if !defined(HAVE_UINT_FAST8_T)
    PRINTF("\tuint_fast8_t\n");
#endif

#if !defined(HAVE_UINT_LEAST16_T)
    PRINTF("\tuint_least16_t\n");
#endif

#if !defined(HAVE_UINT_LEAST32_T)
    PRINTF("\tuint_least32_t\n");
#endif

#if !defined(HAVE_UINT_LEAST64_T)
    PRINTF("\tuint_least64_t\n");
#endif

#if !defined(HAVE_UINT_LEAST8_T)
    PRINTF("\tuint_least8_t\n");
#endif

#if !defined(HAVE_WCHAR_T)
    PRINTF("\twchar_t\n");
#endif

#if !defined(HAVE_WCHAR_T)
    PRINTF("\twchar_t\n");
#endif

#if !defined(HAVE_WCTRANS_T)
    PRINTF("\twctrans_t\n");
#endif

#if !defined(HAVE_WCTYPE_T)
    PRINTF("\twctype_t\n");
#endif

#if !defined(HAVE_WINT_T)
    PRINTF("\twint_t\n");
#endif

#if !defined(HAVE__BOOL)
    PRINTF("\t_Bool\n");
#endif

#if !defined(HAVE__COMPLEX)
    PRINTF("\t_Complex\n");
#endif

#if !defined(HAVE__IMAGINARY)
    PRINTF("\t_Imaginary\n");
#endif

    PRINTF("\n\n");

    /* ============================================================== */

#if defined(HAVE_UNISTD_H) && defined(_PC_NAME_MAX) && defined(_PC_PATH_MAX)
    PRINTF("fpathconf() and pathconf() tests...\n");

    PRINTF("\tpathconf(\"/\", _PC_NAME_MAX)              = %5ld\n",
	   (long int)pathconf("/", _PC_NAME_MAX));
    PRINTF("\tpathconf(\"/bin\", _PC_NAME_MAX)           = %5ld\n",
	   (long int)pathconf("/bin", _PC_NAME_MAX));
    PRINTF("\tpathconf(\"/etc\", _PC_NAME_MAX)           = %5ld\n",
	   (long int)pathconf("/etc", _PC_NAME_MAX));
    PRINTF("\tpathconf(\"/tmp\", _PC_NAME_MAX)           = %5ld\n",
	   (long int)pathconf("/tmp", _PC_NAME_MAX));
    PRINTF("\tpathconf(\"/usr\", _PC_NAME_MAX)           = %5ld\n",
	   (long int)pathconf("/usr", _PC_NAME_MAX));
    PRINTF("\tpathconf(\"/var\", _PC_NAME_MAX)           = %5ld\n",
	   (long int)pathconf("/var", _PC_NAME_MAX));
    PRINTF("\tpathconf(\"./\", _PC_NAME_MAX)             = %5ld\n",
	   (long int)pathconf("./", _PC_NAME_MAX));

    PRINTF("\tfpathconf(fileno(stdin),  _PC_NAME_MAX)  = %5ld\n",
	   (long int)fpathconf(fileno(stdin),  _PC_NAME_MAX));
    PRINTF("\tfpathconf(fileno(stdout),  _PC_NAME_MAX) = %5ld\n",
	   (long int)fpathconf(fileno(stdout),  _PC_NAME_MAX));
    PRINTF("\tfpathconf(fileno(stderr),  _PC_NAME_MAX) = %5ld\n",
	   (long int)fpathconf(fileno(stderr),  _PC_NAME_MAX));

    PRINTF("\n");

    PRINTF("\tpathconf(\"/\", _PC_PATH_MAX)              = %5ld\n",
	   (long int)pathconf("/", _PC_PATH_MAX));
    PRINTF("\tpathconf(\"/bin\", _PC_PATH_MAX)           = %5ld\n",
	   (long int)pathconf("/bin", _PC_PATH_MAX));
    PRINTF("\tpathconf(\"/etc\", _PC_PATH_MAX)           = %5ld\n",
	   (long int)pathconf("/etc", _PC_PATH_MAX));
    PRINTF("\tpathconf(\"/tmp\", _PC_PATH_MAX)           = %5ld\n",
	   (long int)pathconf("/tmp", _PC_PATH_MAX));
    PRINTF("\tpathconf(\"/usr\", _PC_PATH_MAX)           = %5ld\n",
	   (long int)pathconf("/usr", _PC_PATH_MAX));
    PRINTF("\tpathconf(\"/var\", _PC_PATH_MAX)           = %5ld\n",
	   (long int)pathconf("/var", _PC_PATH_MAX));
    PRINTF("\tpathconf(\"./\", _PC_PATH_MAX)             = %5ld\n",
	   (long int)pathconf("./", _PC_PATH_MAX));

    PRINTF("\tfpathconf(fileno(stdin),  _PC_PATH_MAX)  = %5ld\n",
	   (long int)fpathconf(fileno(stdin),  _PC_PATH_MAX));
    PRINTF("\tfpathconf(fileno(stdout),  _PC_PATH_MAX) = %5ld\n",
	   (long int)fpathconf(fileno(stdout),  _PC_PATH_MAX));
    PRINTF("\tfpathconf(fileno(stderr),  _PC_PATH_MAX) = %5ld\n",
	   (long int)fpathconf(fileno(stderr),  _PC_PATH_MAX));
#endif

    show_floats();
    show_doubles();
    show_long_doubles();

    PRINTF("\n\n");
    PRINTF("FEATURES TESTS COMPLETED\n\n");

    return (EXIT_SUCCESS);
}
